[Telepathy-commits] [telepathy-qt4/master] PendingChannel: Changed handle/handleType to targetHandle/targetHandleType.

Andre Moreira Magalhaes (andrunko) andre.magalhaes at collabora.co.uk
Fri Mar 13 14:13:15 PDT 2009


Changed handle/handleType to targetHandle/targetHandleType to be consistent with
Channel API.
---
 TelepathyQt4/Client/connection.cpp      |    2 +-
 TelepathyQt4/Client/pending-channel.cpp |    6 +++---
 TelepathyQt4/Client/pending-channel.h   |    4 ++--
 3 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/TelepathyQt4/Client/connection.cpp b/TelepathyQt4/Client/connection.cpp
index 372ad3a..8eb635f 100644
--- a/TelepathyQt4/Client/connection.cpp
+++ b/TelepathyQt4/Client/connection.cpp
@@ -982,7 +982,7 @@ void Connection::gotContactListChannel(PendingOperation *op)
 
     PendingChannel *pending = qobject_cast<PendingChannel*>(op);
     ChannelPtr channel = pending->channel();
-    uint handle = pending->handle();
+    uint handle = pending->targetHandle();
     Q_ASSERT(channel);
     Q_ASSERT(handle);
     for (int i = 0; i < ContactManager::ContactListChannel::LastType; ++i) {
diff --git a/TelepathyQt4/Client/pending-channel.h b/TelepathyQt4/Client/pending-channel.h
index b787791..3db51a4 100644
--- a/TelepathyQt4/Client/pending-channel.h
+++ b/TelepathyQt4/Client/pending-channel.h
@@ -55,9 +55,9 @@ public:
 
     const QString &channelType() const;
 
-    uint handleType() const;
+    uint targetHandleType() const;
 
-    uint handle() const;
+    uint targetHandle() const;
 
     QVariantMap immutableProperties() const;
 
diff --git a/TelepathyQt4/Client/pending-channel.cpp b/TelepathyQt4/Client/pending-channel.cpp
index 418db17..219876d 100644
--- a/TelepathyQt4/Client/pending-channel.cpp
+++ b/TelepathyQt4/Client/pending-channel.cpp
@@ -186,7 +186,7 @@ const QString &PendingChannel::channelType() const
  *
  * \return The handle type, as specified in #HandleType.
  */
-uint PendingChannel::handleType() const
+uint PendingChannel::targetHandleType() const
 {
     return mPriv->handleType;
 }
@@ -194,11 +194,11 @@ uint PendingChannel::handleType() const
 /**
  * If the channel request has finished, return the target handle of the
  * resulting channel. Otherwise, return the target handle that was requested
  * (which might be different in some situations - see handleType).
  *
  * \return The handle.
  */
-uint PendingChannel::handle() const
+uint PendingChannel::targetHandle() const
 {
     return mPriv->handle;
 }
@@ -194,11 +194,11 @@ uint PendingChannel::handleType() const
  * If the channel request has finished, return the target handle of the
  * resulting channel. Otherwise, return the target handle that was requested
- * (which might be different in some situations - see handleType).
+ * (which might be different in some situations - see targetHandleType).
  *
  * \return The handle.
-- 
1.5.6.5




More information about the telepathy-commits mailing list